# clean up local variables
if ($targetDir)
{
    Clear-Variable targetdir
}

if ($amplitudeDeviceID)
{
    Clear-Variable amplitudeDeviceID
}

# extract information
if (Test-Path "HKLM:\Software\WOW6432Node\Barco\ClickShare Installer")
{
    Try
    {
        $targetDir = Get-ItemPropertyValue -Path "HKLM:\Software\WOW6432Node\Barco\ClickShare Installer" -Name TARGETDIR
    }
    Catch { }

    if ($targetDir)
    {
        Write-Host "[Property] TARGETDIR: '$targetDir' found!"
    }
}

if (Test-Path "HKCU:\SOFTWARE\Barco\ClickShare Client")
{
    Try
    {
        $amplitudeDeviceID = Get-ItemPropertyValue -Path "HKCU:\SOFTWARE\Barco\ClickShare Client" -Name Amplitude-DeviceID
    }
    Catch { }

    if ($amplitudeDeviceID)
    {
        Write-Host "[Property] Amplitude-DeviceID: '$amplitudeDeviceID' found!"
    }
}

################################################################################
# Uninstall ClickShare MSI
################################################################################

if (Get-Package -Name "ClickShare* Machine-Wide Installer" -ErrorAction SilentlyContinue)
{
    Write-Host "[MSI] ClickShare Machine-Wide Installer found!"
    Get-Package -Name "ClickShare* Machine-Wide Installer" | Uninstall-Package -Force
    Write-Host "[MSI] ClickShare Machine-Wide Installer is uninstalled..."
}

################################################################################
# Uninstall conference beta driver
################################################################################

if (Get-Package "ClickShare Conference BETA drivers" -ErrorAction SilentlyContinue)
{
    Write-Host "[MSI] ClickShare Conference BETA drivers found!"
    Get-Package -Name "ClickShare Conference BETA drivers" | Uninstall-Package -Force
    Write-Host "[MSI] ClickShare Conference BETA drivers is uninstalled..."
}

################################################################################
# Uninstall ClickShare setup
################################################################################

# kill the process of clickshare_native
if (Get-Process -Name "clickshare_native" -ErrorAction SilentlyContinue)
{
    Write-Host "[Process] clickshare_native found!"
    Get-Process -Name "clickshare_native" | Stop-Process
    Write-Host "[Process] clickshare_native is stopping..."
}

# kill the process of PresentSense
if (Get-Process -Name "PresentSense" -ErrorAction SilentlyContinue)
{
    Write-Host "[Process] PresentSense found!"
    Get-Process -Name "PresentSense" | Stop-Process
    Write-Host "[Process] PresentSense is stopping..."
}

# kill the process of calendar reader 32 bits version
if (Get-Process -Name "calendarreader32" -ErrorAction SilentlyContinue)
{
    Write-Host "[Process] calendarreader32 found!"
    Get-Process -Name "calendarreader32" | Stop-Process
    Write-Host "[Process] calendarreader32 is stopping..."
}

# kill the process of calendar reader 64 bits version
if (Get-Process -Name "calendarreader64" -ErrorAction SilentlyContinue)
{
    Write-Host "[Process] calendarreader64 found!"
    Get-Process -Name "calendarreader64" | Stop-Process
    Write-Host "[Process] calendarreader64 is stopping..."
}

# exit web component
if (Get-Process -Name "WebComponent" -ErrorAction SilentlyContinue)
{
    Write-Host "[Process] WebComponent found!"

    if (Test-Path -Path "$targetDir\ClickShare\WebComponent.exe" -PathType leaf)
    {
        Start-Process -NoNewWindow -FilePath "$($targetDir)\ClickShare\WebComponent.exe" -ArgumentList "-exit"
        Write-Host "[Process] WebComponent is stopping..."
        Start-Sleep -s 30
    }
    elseif (Test-Path -Path "$env:LOCALAPPDATA\ClickShare\WebComponent.exe" -PathType leaf)
    {
        Start-Process -NoNewWindow -FilePath "$($env:LOCALAPPDATA)\ClickShare\WebComponent.exe" -ArgumentList "-exit"
        Write-Host "[Process] WebComponent is stopping..."
        Start-Sleep -s 30
    }
    else
    {
        Write-Host "[Process] Can NOT find WebComponent.exe!!!"
    }
}

# remove the registry keys of ClickShare
if (Test-Path "HKCU:\Software\Barco\ClickShare Client")
{
    Write-Host "[Registry] 'HKCU:\Software\Barco\ClickShare Client' found!"
    Remove-Item -Path "HKCU:\Software\Barco\ClickShare Client" -Recurse
    Write-Host "[Registry] 'HKCU:\Software\Barco\ClickShare Client' is removed..."
}

if (Test-Path "HKCU:\Software\Barco\ClickShare Installer")
{
    Write-Host "[Registry] 'HKCU:\Software\Barco\ClickShare Installer' found!"
    Remove-Item -Path "HKCU:\Software\Barco\ClickShare Installer" -Recurse
    Write-Host "[Registry] 'HKCU:\Software\Barco\ClickShare Installer' is removed..."
}

if ($amplitudeDeviceID)
{
    Write-Host "[Registry] Recover Amplitude Device ID."
    New-Item -Path "HKCU:\Software\Barco" -Name "ClickShare Client"
    New-ItemProperty -Path "HKCU:\SOFTWARE\Barco\ClickShare Client" -Name "Amplitude-DeviceID" -Value $amplitudeDeviceID
}

# remove the uninstall entry of ClickShare
if (Test-Path "HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\ClickShare")
{
    Write-Host "[Registry] 'HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\ClickShare' found!"
    Remove-Item -Path "HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\ClickShare"
    Write-Host "[Registry] 'HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall\ClickShare' is removed..."
}

# remove the folder of ClickShare
if (Test-Path "$env:LOCALAPPDATA\ClickShare")
{
    Write-Host "[Folder] '$env:LOCALAPPDATA\ClickShare' found!"
    Remove-Item -Path "$env:LOCALAPPDATA\ClickShare" -Recurse -Force -ErrorAction SilentlyContinue
    Write-Host "[Folder] '$env:LOCALAPPDATA\ClickShare' is removing..."
}

if ($targetDir -and (Test-Path $targetDir))
{
    Write-Host "[Folder] '$targetDir' found!"
    Remove-Item -Path $targetDir -Recurse -Force -ErrorAction SilentlyContinue
    Write-Host "[Folder] '$targetDir' is removing"
}

# remove the folder of Barco
if (Test-Path "$env:LOCALAPPDATA\Barco")
{
    Write-Host "[Folder] '$env:LOCALAPPDATA\Barco' found!"
    Remove-Item -Path "$env:LOCALAPPDATA\Barco" -Recurse -Force -ErrorAction SilentlyContinue
    Write-Host "[Folder] '$env:LOCALAPPDATA\Barco' is removing..."
}

# remove the folder of SquirrelTemp
if (Test-Path "$env:LOCALAPPDATA\SquirrelTemp")
{
    Write-Host "[Folder] '$env:LOCALAPPDATA\SquirrelTemp' found!"
    Remove-Item -Path "$env:LOCALAPPDATA\SquirrelTemp" -Recurse -Force -ErrorAction SilentlyContinue
    Write-Host "[Folder] '$env:LOCALAPPDATA\SquirrelTemp' is removing..."
}

# remove shortcut in the Start Menu
if (Test-Path "$env:APPDATA\Microsoft\Windows\Start Menu\Programs\Barco\ClickShare.lnk")
{
    Write-Host "[Shortcut] $env:APPDATA\Microsoft\Windows\Start Menu\Programs\Barco\ClickShare.lnk found!"
    Remove-Item -Path "$env:APPDATA\Microsoft\Windows\Start Menu\Programs\Barco\ClickShare.lnk" -ErrorAction SilentlyContinue
    Write-Host "[Shortcut] $env:APPDATA\Microsoft\Windows\Start Menu\Programs\Barco\ClickShare.lnk is removing..."
}

# remove shortcut in the Desktop
if (Test-Path "$env:USERPROFILE\Desktop\ClickShare.lnk")
{
    Write-Host "[Shortcut] $env:USERPROFILE\Desktop\ClickShare.lnk found!"
    Remove-Item -Path "$env:USERPROFILE\Desktop\ClickShare.lnk" -ErrorAction SilentlyContinue
    Write-Host "[Shortcut] $env:USERPROFILE\Desktop\ClickShare.lnk is removing..."
}

# remove the firewall rule of ClickShare
If (Get-NetFirewallRule -DisplayName "ClickShare*")
{
    Write-Host "[Firewall] ClickShare firewall rule found!"
    Get-NetFirewallRule -DisplayName "ClickShare*" | Remove-NetFirewallRule
    Write-Host "[Firewall] ClickShare firewall rule is removing..."
}

# SIG # Begin signature block
# MIIroQYJKoZIhvcNAQcCoIIrkjCCK44CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCADiGfbOW1GUVg4
# dlcsD/+iJ6dHLeQBq/wl6OGqGAx/U6CCDgowggbmMIIEzqADAgECAhB3vQ4DobcI
# +FSrBnIQ2QRHMA0GCSqGSIb3DQEBCwUAMFMxCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMSkwJwYDVQQDEyBHbG9iYWxTaWduIENvZGUgU2ln
# bmluZyBSb290IFI0NTAeFw0yMDA3MjgwMDAwMDBaFw0zMDA3MjgwMDAwMDBaMFkx
# CzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMS8wLQYDVQQD
# EyZHbG9iYWxTaWduIEdDQyBSNDUgQ29kZVNpZ25pbmcgQ0EgMjAyMDCCAiIwDQYJ
# KoZIhvcNAQEBBQADggIPADCCAgoCggIBANZCTfnjT8Yj9GwdgaYw90g9z9DljeUg
# IpYHRDVdBs8PHXBg5iZU+lMjYAKoXwIC947Jbj2peAW9jvVPGSSZfM8RFpsfe2vS
# o3toZXer2LEsP9NyBjJcW6xQZywlTVYGNvzBYkx9fYYWlZpdVLpQ0LB/okQZ6dZu
# bD4Twp8R1F80W1FoMWMK+FvQ3rpZXzGviWg4QD4I6FNnTmO2IY7v3Y2FQVWeHLw3
# 3JWgxHGnHxulSW4KIFl+iaNYFZcAJWnf3sJqUGVOU/troZ8YHooOX1ReveBbz/IM
# BNLeCKEQJvey83ouwo6WwT/Opdr0WSiMN2WhMZYLjqR2dxVJhGaCJedDCndSsZlR
# Qv+hst2c0twY2cGGqUAdQZdihryo/6LHYxcG/WZ6NpQBIIl4H5D0e6lSTmpPVAYq
# gK+ex1BC+mUK4wH0sW6sDqjjgRmoOMieAyiGpHSnR5V+cloqexVqHMRp5rC+QBmZ
# y9J9VU4inBDgoVvDsy56i8Te8UsfjCh5MEV/bBO2PSz/LUqKKuwoDy3K1JyYikpt
# WjYsL9+6y+JBSgh3GIitNWGUEvOkcuvuNp6nUSeRPPeiGsz8h+WX4VGHaekizIPA
# tw9FbAfhQ0/UjErOz2OxtaQQevkNDCiwazT+IWgnb+z4+iaEW3VCzYkmeVmda6tj
# cWKQJQ0IIPH/AgMBAAGjggGuMIIBqjAOBgNVHQ8BAf8EBAMCAYYwEwYDVR0lBAww
# CgYIKwYBBQUHAwMwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQU2rONwCSQ
# o2t30wygWd0hZ2R2C3gwHwYDVR0jBBgwFoAUHwC/RoAK/Hg5t6W0Q9lWULvOljsw
# gZMGCCsGAQUFBwEBBIGGMIGDMDkGCCsGAQUFBzABhi1odHRwOi8vb2NzcC5nbG9i
# YWxzaWduLmNvbS9jb2Rlc2lnbmluZ3Jvb3RyNDUwRgYIKwYBBQUHMAKGOmh0dHA6
# Ly9zZWN1cmUuZ2xvYmFsc2lnbi5jb20vY2FjZXJ0L2NvZGVzaWduaW5ncm9vdHI0
# NS5jcnQwQQYDVR0fBDowODA2oDSgMoYwaHR0cDovL2NybC5nbG9iYWxzaWduLmNv
# bS9jb2Rlc2lnbmluZ3Jvb3RyNDUuY3JsMFYGA1UdIARPME0wQQYJKwYBBAGgMgEy
# MDQwMgYIKwYBBQUHAgEWJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9z
# aXRvcnkvMAgGBmeBDAEEATANBgkqhkiG9w0BAQsFAAOCAgEACIhyJsav+qxfBsCq
# jJDa0LLAopf/bhMyFlT9PvQwEZ+PmPmbUt3yohbu2XiVppp8YbgEtfjry/RhETP2
# ZSW3EUKL2Glux/+VtIFDqX6uv4LWTcwRo4NxahBeGQWn52x/VvSoXMNOCa1Za7j5
# fqUuuPzeDsKg+7AE1BMbxyepuaotMTvPRkyd60zsvC6c8YejfzhpX0FAZ/ZTfepB
# 7449+6nUEThG3zzr9s0ivRPN8OHm5TOgvjzkeNUbzCDyMHOwIhz2hNabXAAC4ShS
# S/8SS0Dq7rAaBgaehObn8NuERvtz2StCtslXNMcWwKbrIbmqDvf+28rrvBfLuGfr
# 4z5P26mUhmRVyQkKwNkEcUoRS1pkw7x4eK1MRyZlB5nVzTZgoTNTs/Z7KtWJQDxx
# pav4mVn945uSS90FvQsMeAYrz1PYvRKaWyeGhT+RvuB4gHNU36cdZytqtq5NiYAk
# CFJwUPMB/0SuL5rg4UkI4eFb1zjRngqKnZQnm8qjudviNmrjb7lYYuA2eDYB+sGn
# iXomU6Ncu9Ky64rLYwgv/h7zViniNZvY/+mlvW1LWSyJLC9Su7UpkNpDR7xy3bzZ
# v4DB3LCrtEsdWDY3ZOub4YUXmimi/eYI0pL/oPh84emn0TCOXyZQK8ei4pd3iu/Y
# TT4m65lAYPM8Zwy2CHIpNVOBNNwwggccMIIFBKADAgECAgwfOUOJ5IZAnfrVzIMw
# DQYJKoZIhvcNAQELBQAwWTELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNp
# Z24gbnYtc2ExLzAtBgNVBAMTJkdsb2JhbFNpZ24gR0NDIFI0NSBDb2RlU2lnbmlu
# ZyBDQSAyMDIwMB4XDTIxMDYwODEzNDkyMFoXDTI0MDYwODEzNDkyMFowgYkxCzAJ
# BgNVBAYTAkJFMRgwFgYDVQQIEw9XZXN0LVZsYWFuZGVyZW4xETAPBgNVBAcTCEtv
# cnRyaWprMRMwEQYDVQQKEwpCYXJjbyBOLlYuMRMwEQYDVQQDEwpCYXJjbyBOLlYu
# MSMwIQYJKoZIhvcNAQkBFhRjbGlja3NoYXJlQGJhcmNvLmNvbTCCAiIwDQYJKoZI
# hvcNAQEBBQADggIPADCCAgoCggIBAL/FFJsA3SIv1KwCCV4iMkqFHNhRnFGdu2wO
# ysWnuLDc0JKSFDDJfHF7sJROajSexc5bLiH3l8sTZy0TGe3onJNdis5Qt8t8yjgC
# Ccq3VXqRGti48y+qYbTNoqjwd1moKoWDUdGfX6YlqW/eKtbTKvtt4wzij/mP0iTn
# Ne2GcdD65JV35gg301ruFpeL2S8L0gXTw/huzVjfcn/6I0fGalWexgaNwdilHVFL
# 7Wyu66pVl8ayCIvzLpEgt2EG7WVxNu26Za99Jqi8zFndvI9x8TPCOTU131iN2zNJ
# cSm8XkJMbLvayAcTO2g9EjkpjLmIP7Gm4yk+dYi/3WSO0e0MsWlPJhNOIbJ8fr5g
# X2RT31spO+tU06hx+yU+sXNZjGpyRcgZPE4TLheDSOug5nC7x63M/OFDeRx26LRu
# puDvCSxFA3ftcqTFhYQVL+K/o26B7hmL+de87aNlez+Bb4JVqocT8n2TuV2fQyWE
# dlseNADKHIHGz5qpPjIlyy9S6W56+DUIfR96tJmLtPDVWEOjSfe+34C20JksqHxO
# ygsleYlv7eN928VeOCuhD5+twEbzqELqqOPfGYBzZK2wnqvpuW1uu3pKVkNktHyg
# vbaoTFqb5ig4VH5dPYg7ieSgYeyf866xPzyfP2uIG+Sdwd1pZ7Dc7pyMQti15V62
# 35xnI0i1AgMBAAGjggGxMIIBrTAOBgNVHQ8BAf8EBAMCB4AwgZsGCCsGAQUFBwEB
# BIGOMIGLMEoGCCsGAQUFBzAChj5odHRwOi8vc2VjdXJlLmdsb2JhbHNpZ24uY29t
# L2NhY2VydC9nc2djY3I0NWNvZGVzaWduY2EyMDIwLmNydDA9BggrBgEFBQcwAYYx
# aHR0cDovL29jc3AuZ2xvYmFsc2lnbi5jb20vZ3NnY2NyNDVjb2Rlc2lnbmNhMjAy
# MDBWBgNVHSAETzBNMEEGCSsGAQQBoDIBMjA0MDIGCCsGAQUFBwIBFiZodHRwczov
# L3d3dy5nbG9iYWxzaWduLmNvbS9yZXBvc2l0b3J5LzAIBgZngQwBBAEwCQYDVR0T
# BAIwADBFBgNVHR8EPjA8MDqgOKA2hjRodHRwOi8vY3JsLmdsb2JhbHNpZ24uY29t
# L2dzZ2NjcjQ1Y29kZXNpZ25jYTIwMjAuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMD
# MB8GA1UdIwQYMBaAFNqzjcAkkKNrd9MMoFndIWdkdgt4MB0GA1UdDgQWBBSInvk7
# ivn5dumlhLaBSY5WOcnTaTANBgkqhkiG9w0BAQsFAAOCAgEAUBdTzIukS79LfAhI
# PFGV7w0dhuCsoZ18epEEsfcgJvY99VfjEag0kejcDdw2o51mgxlUhvCZ67mGWajm
# CglXjpaDa8+eMaSm3DJvdQnjpA2COV1GWSBcP/Ap8dzsTH40N8oaHNw5jqWNYxiD
# aCb2IoxcCBcXatig/0CuI+95vNcyNetvXr/KTf6Agce7yr671Z9898+/5X0ZUOaw
# w3LBnl4S1LK+jJ2R8YwbE+2Uz7MY6f7y9TrkTzT3t8sWmm9/wfFejW+eWRGAiN9o
# L0e7icwJwlOVvUfkltdF4p4YkFvjiSoiVtYSBoJJzGo58SALI0oihB54Abfy8o4o
# zpZx9493b0eJv39eMJYz4w9zR+bnYWx9obCNIBVD03vix61lvJLMh/FEtZ9FeIYY
# Vk/idXtNZZofjY6xKzlyBtclDkRStIKvikERKtkqNoSk6g/4VlNOX5iNIY6B6peI
# d6C3Hxu5mbsBsdVbbGVW/zRx7pDzWGmi2fLBjdAMjN93kEuNT9MhOxp64AXXLbS9
# QDnShQpH71/+X9HLpaG1aF+LPG7/uaxgVUrn87Hxc2WaEAwKliRpgZlwpOoCRPWO
# BggSMAVXplOFw5rlU77W7fQ5iWdFY4L+lTsSVmTA1lWtFY7s6vpB0WeDs0CGhp6c
# xgG1lbVCWs8CwgU2WgXQLtWJfawxghztMIIc6QIBATBpMFkxCzAJBgNVBAYTAkJF
# MRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMS8wLQYDVQQDEyZHbG9iYWxTaWdu
# IEdDQyBSNDUgQ29kZVNpZ25pbmcgQ0EgMjAyMAIMHzlDieSGQJ361cyDMA0GCWCG
# SAFlAwQCAQUAoHwwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZIhvcNAQkDMQwGCisG
# AQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcN
# AQkEMSIEIMy/qqRX4UDceNp1VC9VDWJlqpRcIWbTS1deij0rnAJaMA0GCSqGSIb3
# DQEBAQUABIICAK3aytSr/yYqqXxDzScEaVzfIBXjJx82Z6NtIxkZAlvNHj3TrkqQ
# 3Cs/JjGfCuydeQ/caxaimLMGqgULXp6BKRALum2RywGbKsEaJKbM8LxzE7uAZ8zb
# 7btwVtyAQjcjQky0nclT+93e7nYveSs2lhMsvyLubIDbndlosLN1isY6poPoEuT3
# fWyVS+pcnhHxZQtNij/8YR2U5rG+186WukAtAEWGFSZZeUK6Z+HqpHQdANpr1zqK
# 52rcAbqhTkI0uaXTpLfAC0vl8LYsM5JEZU4i9sA8ZxGlsiiYofc26qvKJRZUQxq0
# dm/yaP6LlMmnetb79qvpMKvC02kqK6RSB6lmvchOIrAkWxVuUTtH/59Qj/FrDnyv
# jbkmOUJjA0Gl6Mqlx1Igi4zCsIGICunm9dRpsD9xwDAN9Jg0J3V0m+paG3c02wsJ
# pcPqGYZ/4266FhdK7oA+uznC78evx8pYs/o9P1H13GIY2ZBMhiPcWlIo+wFKG+Zr
# 7O0IWnb0cLyGfQMwKiCtjJiXTNK3f8yH6676mmjDwgRQXUMvdRcWYD2cLQCPPxnO
# pQ1ZNCs2B4OY2ZkeGbFcYa4AII7ZoF226o9YyRde4VcrN0w5gtFfx/MlU/c35y+K
# kGKTC/L9QJEwEnBIttMiE9P2u/gog5ZZTYdCFtD3fWP0muhI+vLsgZQZoYIZ1zCC
# GdMGCisGAQQBgjcDAwExghnDMIIZvwYJKoZIhvcNAQcCoIIZsDCCGawCAQMxDzAN
# BglghkgBZQMEAgEFADCB3AYLKoZIhvcNAQkQAQSggcwEgckwgcYCAQEGCSsGAQQB
# oDICAzAxMA0GCWCGSAFlAwQCAQUABCALf+CDOYsWGY+4t+ydjoXwi3ymI9WuuPGp
# P7MB4tV+9gIUGDOOLJz9kNaXg0qdw4ldpUp68lgYDzIwMjEwOTI4MTQ1MjA0WjAD
# AgEBoFekVTBTMQswCQYDVQQGEwJCRTEZMBcGA1UECgwQR2xvYmFsU2lnbiBudi1z
# YTEpMCcGA1UEAwwgR2xvYmFsc2lnbiBUU0EgZm9yIEFkdmFuY2VkIC0gRzSgghVk
# MIIGVTCCBD2gAwIBAgIQAQBGaVCmBKnZcOgd0k1BnzANBgkqhkiG9w0BAQsFADBb
# MQswCQYDVQQGEwJCRTEZMBcGA1UEChMQR2xvYmFsU2lnbiBudi1zYTExMC8GA1UE
# AxMoR2xvYmFsU2lnbiBUaW1lc3RhbXBpbmcgQ0EgLSBTSEEzODQgLSBHNDAeFw0y
# MTA1MjcwOTU1MjNaFw0zMjA2MjgwOTU1MjJaMFMxCzAJBgNVBAYTAkJFMRkwFwYD
# VQQKDBBHbG9iYWxTaWduIG52LXNhMSkwJwYDVQQDDCBHbG9iYWxzaWduIFRTQSBm
# b3IgQWR2YW5jZWQgLSBHNDCCAaIwDQYJKoZIhvcNAQEBBQADggGPADCCAYoCggGB
# AN8waZh7lw1uo1S0OV9kWXUEIv5OaW/oF3R0pX1RGA5GIB9oLrrlZdbJ0pGh7KT3
# Veqq7TvM+2KbhEKSejJM+fTyHPiY0bkxgSWtrVZnMqb+hzLzXMMtYvFNiQw3tH/r
# KuNgi29sPTHy7cldgJspnVXg4sT/6naTGB5sqat7yR4SYdXA56Dm+JApMyy4v25a
# st3HB0PRO9swC7R4w+zq8aJUz2CTOMz3ZEP1zwgEFnDItNsO1AqKCNy7k8EdbvKM
# nOshNZ7/j7ywfsKEOH7mnWR6JqDxILG84dgqJZ0YUuRt1EwwCnjMLUaO7VcLP3mV
# UKcDsDODMrdAnvS0kpcTDFC3nqq0QU4LmInM+8QhRJAyjkjyLEsMF+SEV1umrPuX
# g/mNZFTC7GpDHs8KdpKyEL/t1qMgD7XRMI4aQLE259COePMTwC8LiJA7CGHjD61H
# sw5UcJV/oEPUWsbdF5+UywCHaA7hrpPuLHIEGzIXkEvXK4AlBR/lM/TowGgqeReg
# 7wIDAQABo4IBmzCCAZcwDgYDVR0PAQH/BAQDAgeAMBYGA1UdJQEB/wQMMAoGCCsG
# AQUFBwMIMB0GA1UdDgQWBBSufnCBeCAUKa3yePhZANnMpiQCjjBMBgNVHSAERTBD
# MEEGCSsGAQQBoDIBHjA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAJBgNVHRMEAjAAMIGQBggrBgEFBQcBAQSBgzCB
# gDA5BggrBgEFBQcwAYYtaHR0cDovL29jc3AuZ2xvYmFsc2lnbi5jb20vY2EvZ3N0
# c2FjYXNoYTM4NGc0MEMGCCsGAQUFBzAChjdodHRwOi8vc2VjdXJlLmdsb2JhbHNp
# Z24uY29tL2NhY2VydC9nc3RzYWNhc2hhMzg0ZzQuY3J0MB8GA1UdIwQYMBaAFOoW
# xmnn48tXRTkzpPBAvtDDvWWWMEEGA1UdHwQ6MDgwNqA0oDKGMGh0dHA6Ly9jcmwu
# Z2xvYmFsc2lnbi5jb20vY2EvZ3N0c2FjYXNoYTM4NGc0LmNybDANBgkqhkiG9w0B
# AQsFAAOCAgEAf2Lo+tl3L0Jvaw/X3UVZPPR1egDsvfZvDiNtLTNCchRPRJSBveuM
# AohMrH/HXc23xCSau5kBaApa6kVh07As132gF+5dgPEa4uf8sd8dMgQoDzaE1wlG
# LbZ+wEAVIhp5YWeXthKP0E9mLC5UKlgGrJlO/XWtVCYKaP+SJ/g8uRltMIEmTIUs
# 83Pcj+DlymRKe0cRTNqi1Lfx5FF65jmwIQcZ4PCMuXFwfZHtNJ+LMZ4NxMY+Nitm
# 1sBB1bIjSSLTvl+JNoxa1sVQqj8OTlQJtv4Nkdlx2J82PDSOiYO35PNmSs43kItd
# euo+o+MHBz2UGRSe+rFnS+u2srcIb5KWRV1M7g5ZWotmc2FFNkqGzmNDGW4GOglG
# OZB0xnMLXkLRzS8ibCQnpwICUZKNAbRdhcf4w0F13WSM8vOY7um3hwmnvQoTMDdi
# H1nnKXJ3aXV4kLDNHDpcahCGcvcAsjKXWXieTvizZv2vK/yJtnWilAo3khNBdd31
# Pzqup6i0QtPZnFES8vJ61ivsnkwl2W2ckfQfAU9Ix+yP+Vuq7PpcEXJgruw3cZS+
# XEmJTClt81c7GgBXvL6QLkJhgtXf/wCBlnwBVZO4YmToBoarVUpvM8Xz2lgFjd0B
# 9TxVIYX+ezV5xX+y+9itvZ35VQokZHRhiiuXNl9WvfLX4Ox8/fnrktQwggZZMIIE
# QaADAgECAg0B7BySQN79LkBdfEd0MA0GCSqGSIb3DQEBDAUAMEwxIDAeBgNVBAsT
# F0dsb2JhbFNpZ24gUm9vdCBDQSAtIFI2MRMwEQYDVQQKEwpHbG9iYWxTaWduMRMw
# EQYDVQQDEwpHbG9iYWxTaWduMB4XDTE4MDYyMDAwMDAwMFoXDTM0MTIxMDAwMDAw
# MFowWzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExMTAv
# BgNVBAMTKEdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENBIC0gU0hBMzg0IC0gRzQw
# ggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDwAuIwI/rgG+GadLOvdYNf
# qUdSx2E6Y3w5I3ltdPwx5HQSGZb6zidiW64HiifuV6PENe2zNMeswwzrgGZt0ShK
# wSy7uXDycq6M95laXXauv0SofEEkjo+6xU//NkGrpy39eE5DiP6TGRfZ7jHPvIo7
# bmrEiPDul/bc8xigS5kcDoenJuGIyaDlmeKe9JxMP11b7Lbv0mXPRQtUPbFUUweL
# mW64VJmKqDGSO/J6ffwOWN+BauGwbB5lgirUIceU/kKWO/ELsX9/RpgOhz16ZevR
# VqkuvftYPbWF+lOZTVt07XJLog2CNxkM0KvqWsHvD9WZuT/0TzXxnA/TNxNS2SU0
# 7Zbv+GfqCL6PSXr/kLHU9ykV1/kNXdaHQx50xHAotIB7vSqbu4ThDqxvDbm19m1W
# /oodCT4kDmcmx/yyDaCUsLKUzHvmZ/6mWLLU2EESwVX9bpHFu7FMCEue1EIGbxsY
# 1TbqZK7O/fUF5uJm0A4FIayxEQYjGeT7BTRE6giunUlnEYuC5a1ahqdm/TMDAd6Z
# JflxbumcXQJMYDzPAo8B/XLukvGnEt5CEk3sqSbldwKsDlcMCdFhniaI/MiyTdtk
# 8EWfusE/VKPYdgKVbGqNyiJc9gwE4yn6S7Ac0zd0hNkdZqs0c48efXxeltY9GbCX
# 6oxQkW2vV4Z+EDcdaxoU3wIDAQABo4IBKTCCASUwDgYDVR0PAQH/BAQDAgGGMBIG
# A1UdEwEB/wQIMAYBAf8CAQAwHQYDVR0OBBYEFOoWxmnn48tXRTkzpPBAvtDDvWWW
# MB8GA1UdIwQYMBaAFK5sBaOTE+Ki5+LXHNbH8H/IZ1OgMD4GCCsGAQUFBwEBBDIw
# MDAuBggrBgEFBQcwAYYiaHR0cDovL29jc3AyLmdsb2JhbHNpZ24uY29tL3Jvb3Ry
# NjA2BgNVHR8ELzAtMCugKaAnhiVodHRwOi8vY3JsLmdsb2JhbHNpZ24uY29tL3Jv
# b3QtcjYuY3JsMEcGA1UdIARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRw
# czovL3d3dy5nbG9iYWxzaWduLmNvbS9yZXBvc2l0b3J5LzANBgkqhkiG9w0BAQwF
# AAOCAgEAf+KI2VdnK0JfgacJC7rEuygYVtZMv9sbB3DG+wsJrQA6YDMfOcYWaxlA
# SSUIHuSb99akDY8elvKGohfeQb9P4byrze7AI4zGhf5LFST5GETsH8KkrNCyz+zC
# VmUdvX/23oLIt59h07VGSJiXAmd6FpVK22LG0LMCzDRIRVXd7OlKn14U7XIQcXZw
# 0g+W8+o3V5SRGK/cjZk4GVjCqaF+om4VJuq0+X8q5+dIZGkv0pqhcvb3JEt0Wn1y
# hjWzAlcfi5z8u6xM3vreU0yD/RKxtklVT3WdrG9KyC5qucqIwxIwTrIIc59eodaZ
# zul9S5YszBZrGM3kWTeGCSziRdayzW6CdaXajR63Wy+ILj198fKRMAWcznt8oMWs
# r1EG8BHHHTDFUVZg6HyVPSLj1QokUyeXgPpIiScseeI85Zse46qEgok+wEr1If5i
# EO0dMPz2zOpIJ3yLdUJ/a8vzpWuVHwRYNAqJ7YJQ5NF7qMnmvkiqK1XZjbclIA4b
# UaDUY6qD6mxyYUrJ+kPExlfFnbY8sIuwuRwx773vFNgUQGwgHcIt6AvGjW2MtnHt
# UiH+PvafnzkarqzSL3ogsfSsqh3iLRSd+pZqHcY8yvPZHL9TTaRHWXyVxENB+SXi
# LBB+gfkNlKd98rUJ9dhgckBQlSDUQ0S++qCV5yBZtnjGpGqqIpswggVHMIIEL6AD
# AgECAg0B8kBCQM79ItvpbHH8MA0GCSqGSIb3DQEBDAUAMEwxIDAeBgNVBAsTF0ds
# b2JhbFNpZ24gUm9vdCBDQSAtIFIzMRMwEQYDVQQKEwpHbG9iYWxTaWduMRMwEQYD
# VQQDEwpHbG9iYWxTaWduMB4XDTE5MDIyMDAwMDAwMFoXDTI5MDMxODEwMDAwMFow
# TDEgMB4GA1UECxMXR2xvYmFsU2lnbiBSb290IENBIC0gUjYxEzARBgNVBAoTCkds
# b2JhbFNpZ24xEzARBgNVBAMTCkdsb2JhbFNpZ24wggIiMA0GCSqGSIb3DQEBAQUA
# A4ICDwAwggIKAoICAQCVB+hzymb57BTKezz3DQjxtEULLIK0SMbrWzyug7hBkjMU
# pG9/6SrMxrCIa8W2idHGsv8UzlEUIexK3RtaxtaH7k06FQbtZGYLkoDKRN5zlE7z
# p4l/T3hjCMgSUG1CZi9NuXkoTVIaihqAtxmBDn7EirxkTCEcQ2jXPTyKxbJm1ZCa
# tzEGxb7ibTIGph75ueuqo7i/voJjUNDwGInf5A959eqiHyrScC5757yTu21T4kh8
# jBAHOP9msndhfuDqjDyqtKT285VKEgdt/Yyyic/QoGF3yFh0sNQjOvddOsqi250J
# 3l1ELZDxgc1Xkvp+vFAEYzTfa5MYvms2sjnkrCQ2t/DvthwTV5O23rL44oW3c6K4
# NapF8uCdNqFvVIrxclZuLojFUUJEFZTuo8U4lptOTloLR/MGNkl3MLxxN+Wm7CEI
# dfzmYRY/d9XZkZeECmzUAk10wBTt/Tn7g/JeFKEEsAvp/u6P4W4LsgizYWYJarEG
# OmWWWcDwNf3J2iiNGhGHcIEKqJp1HZ46hgUAntuA1iX53AWeJ1lMdjlb6vmlodiD
# D9H/3zAR+YXPM0j1ym1kFCx6WE/TSwhJxZVkGmMOeT31s4zKWK2cQkV5bg6HGVxU
# sWW2v4yb3BPpDW+4LtxnbsmLEbWEFIoAGXCDeZGXkdQaJ783HjIH2BRjPChMrwID
# AQABo4IBJjCCASIwDgYDVR0PAQH/BAQDAgEGMA8GA1UdEwEB/wQFMAMBAf8wHQYD
# VR0OBBYEFK5sBaOTE+Ki5+LXHNbH8H/IZ1OgMB8GA1UdIwQYMBaAFI/wS3+oLkUk
# rk1Q+mOai97i3Ru8MD4GCCsGAQUFBwEBBDIwMDAuBggrBgEFBQcwAYYiaHR0cDov
# L29jc3AyLmdsb2JhbHNpZ24uY29tL3Jvb3RyMzA2BgNVHR8ELzAtMCugKaAnhiVo
# dHRwOi8vY3JsLmdsb2JhbHNpZ24uY29tL3Jvb3QtcjMuY3JsMEcGA1UdIARAMD4w
# PAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxzaWduLmNv
# bS9yZXBvc2l0b3J5LzANBgkqhkiG9w0BAQwFAAOCAQEASaxexYPzWsthKk2XShUp
# n+QUkKoJ+cR6nzUYigozFW1yhyJOQT9tCp4YrtviX/yV0SyYFDuOwfA2WXnzjYHP
# dPYYpOThaM/vf2VZQunKVTm808Um7nE4+tchAw+3TtlbYGpDtH0J0GBh3artAF5O
# Mh7gsmyePLLCu5jTkHZqaa0a3KiJ2lhP0sKLMkrOVPs46TsHC3UKEdsLfCUn8awm
# zxFT5tzG4mE1MvTO3YPjGTrrwmijcgDIJDxOuFM8sRer5jUs+dNCKeZfYAOsQmGm
# sVdqM0LfNTGGyj43K9rE2iT1ThLytrm3R+q7IK1hFregM+Mtiae8szwBfyMagAk0
# 6TCCA18wggJHoAMCAQICCwQAAAAAASFYUwiiMA0GCSqGSIb3DQEBCwUAMEwxIDAe
# BgNVBAsTF0dsb2JhbFNpZ24gUm9vdCBDQSAtIFIzMRMwEQYDVQQKEwpHbG9iYWxT
# aWduMRMwEQYDVQQDEwpHbG9iYWxTaWduMB4XDTA5MDMxODEwMDAwMFoXDTI5MDMx
# ODEwMDAwMFowTDEgMB4GA1UECxMXR2xvYmFsU2lnbiBSb290IENBIC0gUjMxEzAR
# BgNVBAoTCkdsb2JhbFNpZ24xEzARBgNVBAMTCkdsb2JhbFNpZ24wggEiMA0GCSqG
# SIb3DQEBAQUAA4IBDwAwggEKAoIBAQDMJXaQeQZ4Ihb1wIO2hMoonv0FdhHFrYhy
# /EYCQ8eyip0EXyTLLkvhYIJG4VKrDIFHcGzdZNHr9SyjD4I9DCuul9e2FIYQebs7
# E4B3jAjhSdJqYi8fXvqWaN+JJ5U4nwbXPsnLJlkNc96wyOkmDoMVxu9bi9IEYMpJ
# pij2aTv2y8gokeWdimFXN6x0FNx04Druci8unPvQu7/1PQDhBjPogiuuU6Y6FnOM
# 3UEOIDrAtKeh6bJPkC4yYOlXy7kEkmho5TgmYHWyn3f/kRTvriBJ/K1AFUjRAjFh
# GV64l++td7dkmnq/X8ET75ti+w1s4FRpFqkD2m7pg5NxdsZphYIXAgMBAAGjQjBA
# MA4GA1UdDwEB/wQEAwIBBjAPBgNVHRMBAf8EBTADAQH/MB0GA1UdDgQWBBSP8Et/
# qC5FJK5NUPpjmove4t0bvDANBgkqhkiG9w0BAQsFAAOCAQEAS0DbwFCq/sgM7/eW
# VEVJu5YACUGssxOGhigHM8pr5nS5ugAtrqQK0/Xx8Q+Kv3NnSoPHRHt44K9ubG8D
# KY4zOUXDjuS5V2yq/BKW7FPGLeQkbLmUY/vcU2hnVj6DuM81IcPJaP7O2sJTqsyQ
# iunwXUaMld16WCgaLx3ezQA3QY/tRG3XUyiXfvNnBB4V14qWtNPeTCekTBtzc3b0
# F5nCH3oO4y0IrQocLP88q1UOD5F+NuvDV0m+4S4tfGCLw0FREyOdzvcya5QBqJnn
# LDMfOjsl0oZAzjsshnjJYS8Uuu7bVW/fhO4FCU29KNhyztNiUGUe65KXgzHZs7XK
# R1g/XzGCA00wggNJAgEBMG8wWzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2Jh
# bFNpZ24gbnYtc2ExMTAvBgNVBAMTKEdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENB
# IC0gU0hBMzg0IC0gRzQCEAEARmlQpgSp2XDoHdJNQZ8wDQYJYIZIAWUDBAIBBQCg
# ggEvMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAtBgkqhkiG9w0BCTQxIDAe
# MA0GCWCGSAFlAwQCAQUAoQ0GCSqGSIb3DQEBCwUAMC8GCSqGSIb3DQEJBDEiBCBF
# zCvfLFGPv6Zmv1wUi9ukvcvQwhwx8lOJj5qaoFBJxTCBsAYLKoZIhvcNAQkQAi8x
# gaAwgZ0wgZowgZcEIBPW6cQg/21OJ1RyjGjneIJlZGfbmhkPgWWX9n+2zMb5MHMw
# X6RdMFsxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMTEw
# LwYDVQQDEyhHbG9iYWxTaWduIFRpbWVzdGFtcGluZyBDQSAtIFNIQTM4NCAtIEc0
# AhABAEZpUKYEqdlw6B3STUGfMA0GCSqGSIb3DQEBCwUABIIBgEavxRwTfXST+1Ou
# h0QE+VIauy4TOojOTXM2zBJQKuwmSwcQ89if4vv1uArmLYTeLs6n1z/V4ILgPZrv
# ednfEvfld+aNdCh4TE9cuJAOptBvrxrB/CeXresLBsdM7hlLZltV0GjbVEXzzJSr
# kIHe/d8ymQR44eW8t8s5+UBndNtw/8U+v6Yqyytrc3nisSzRzQscti8F1gj48uFX
# sFlc1f8h9gZnKfHAH+N7GeVDBjzMOZhv9mRoiU+Q4nj4l9ELkcCEmoPD3cijcLRj
# nHNt2kOSWN52ZnW7TE6fQ+NLt2hOeeSOCuM4zmSYJHc3c9yT0f9xtxhjyZHRG/Q9
# qRGwlNAwZPNsltELUD9s89rRWZy+L3+vweAEfbOIMzAbFmq3recMr01hRlRLeDh6
# +dH4D0zgJnjXKoeMwz/PndpmHhjWnsMohBowKkP/YlHEzBoqRsgXRtK9kJCbOc+u
# 7IJgO5u72DEQ+MEzoyZlcAzJaoSLfI9rdt4V0Wf3u1USn2/dZg==
# SIG # End signature block
